@@ -14,16 +14,16 @@
 #
 # SHA: SHA of a commit to set a status on.
 
-set -e
+set -e -E -u -o pipefail
 
 if [ -z "$GITHUB_ACTIONS" ]; then
   echo "Must be run inside GitHub Actions CI"
-  exit -1
+  exit 1
 fi
 
 if [ $# -ne 3 ]; then
   echo "Usage: $0 <NAME> <STATUS> <SHA>"
-  exit -1
+  exit 1
 fi
 
 name=$1
