@@ -3,6 +3,7 @@
 
 Contributors: https://github.com/microsoft/LightGBM/graphs/contributors.
 """
+
 from pathlib import Path
 
 from .basic import Booster, Dataset, Sequence, register_logger
@@ -23,14 +24,33 @@ except ImportError:
     pass
 
 
-_version_path = Path(__file__).absolute().parent / 'VERSION.txt'
+_version_path = Path(__file__).absolute().parent / "VERSION.txt"
 if _version_path.is_file():
-    __version__ = _version_path.read_text(encoding='utf-8').strip()
+    __version__ = _version_path.read_text(encoding="utf-8").strip()
 
-__all__ = ['Dataset', 'Booster', 'CVBooster', 'Sequence',
-           'register_logger',
-           'train', 'cv',
-           'LGBMModel', 'LGBMRegressor', 'LGBMClassifier', 'LGBMRanker',
-           'DaskLGBMRegressor', 'DaskLGBMClassifier', 'DaskLGBMRanker',
-           'log_evaluation', 'record_evaluation', 'reset_parameter', 'early_stopping', 'EarlyStopException',
-           'plot_importance', 'plot_split_value_histogram', 'plot_metric', 'plot_tree', 'create_tree_digraph']
+__all__ = [
+    "Dataset",
+    "Booster",
+    "CVBooster",
+    "Sequence",
+    "register_logger",
+    "train",
+    "cv",
+    "LGBMModel",
+    "LGBMRegressor",
+    "LGBMClassifier",
+    "LGBMRanker",
+    "DaskLGBMRegressor",
+    "DaskLGBMClassifier",
+    "DaskLGBMRanker",
+    "log_evaluation",
+    "record_evaluation",
+    "reset_parameter",
+    "early_stopping",
+    "EarlyStopException",
+    "plot_importance",
+    "plot_split_value_histogram",
+    "plot_metric",
+    "plot_tree",
+    "create_tree_digraph",
+]
